@@ -304,8 +304,9 @@ def sort_file(
                                 file_output=tmp_file.read_text(encoding=source_file.encoding),
                                 file_path=file_path or source_file.path,
                             )
-                            if ask_to_apply and not ask_whether_to_apply_changes_to_file(
-                                str(source_file.path)
+                            if show_diff or (
+                                ask_to_apply
+                                and not ask_whether_to_apply_changes_to_file(str(source_file.path))
                             ):
                                 return
                         source_file.stream.close()
@@ -527,7 +528,9 @@ def _sort_imports(
 
             if import_section:
                 if add_imports and not indent:
-                    import_section += line_separator.join(add_imports) + line_separator
+                    import_section = (
+                        line_separator.join(add_imports) + line_separator + import_section
+                    )
                     contains_imports = True
                     add_imports = []
 
@@ -551,7 +554,9 @@ def _sort_imports(
                             line.lstrip() for line in import_section.split(line_separator)
                         )
                         out_config = Config(
-                            config=config, line_length=max(config.line_length - len(indent), 0)
+                            config=config,
+                            line_length=max(config.line_length - len(indent), 0),
+                            lines_after_imports=1,
                         )
                     else:
                         out_config = config
